<?php

namespace Sprinix\RequestQuote\Block;

use Magento\Framework\View\Element\Template;
use Magento\Backend\Block\Template\Context;
use Sprinix\RequestQuote\Model\ResourceModel\QuoteItem\CollectionFactory;
use Magento\Checkout\Model\Session as CheckoutSession;
use Magento\Customer\Model\Session;
use Magento\Framework\Session\SessionManagerInterface;
use Sprinix\RequestQuote\Model\QuoteFactory;
use  Magento\Framework\App\Http\Context as HttpContext;

/**
 * Class Customerviewdata
 * @package Sprinix\RequestQuote\Block
 */
class Customerviewdata extends Template
{
    /**
     * @var CollectionFactory
     */
    public $collection;
    /**
     * @var \Sprinix\RequestQuote\Model\QuoteFactory
     */
    protected $quoteFactory;

    /**
     * @var \Magento\Customer\Model\Session
     */
    protected $customerSession;

    /**
     * @var
     */
    protected $httpContext;

    /**
     * Customerviewdata constructor.
     * @param Context $context
     * @param CollectionFactory $collectionFactory
     * @param Session $customerSession
     * @param CheckoutSession $checkoutSession
     * @param SessionManagerInterface $coreSession
     * @param QuoteFactory $quoteFactory
     * @param HttpContext $httpContext
     * @param array $data
     */
    public function __construct(
        Context $context,
        CollectionFactory $collectionFactory,
        Session $customerSession,
        CheckoutSession $checkoutSession,
        SessionManagerInterface $coreSession,
        QuoteFactory $quoteFactory,
        HttpContext $httpContext,
        array $data = [])
    {
        $this->checkoutSession = $checkoutSession;
        $this->collection = $collectionFactory;
        $this->quoteFactory = $quoteFactory;
        $this->customerSession = $customerSession;
        $this->mysession = $coreSession;
        $this->httpContext = $httpContext;
        parent::__construct($context, $data);
    }

    /**
     * @return array
     */
    public function getDataCollection()
    {
        try {
            $customer_id = $this->httpContext->getValue('customer_id');
            $submittedQuote = $this->getRequest()->getParam('id');
            if ($submittedQuote) {
                $models = $this->quoteFactory->create()
                    ->getCollection()
                    ->addFieldToFilter('customer_id', $customer_id)
                    ->addFieldToFilter('customer_action_status', 'submitted')
                    ->getFirstItem()
                    ->getData();
                if ($models) {
                    $var = $this->collection->create();
                    $var->addFieldToFilter('quote_id', ['eq' => $submittedQuote]);
                    $data = $var->getData();
                    return $data;
                }
            } else {
                $models = $this->quoteFactory->create()
                    ->getCollection()
                    ->addFieldToFilter('customer_id', $customer_id)
                    ->addFieldToFilter('customer_action_status', 'preparing')
                    ->getFirstItem()
                    ->getData();
                if ($models) {
                    $var = $this->collection->create();
                    $var->addFieldToFilter('quote_id', ['eq' => $models['quote_id']]);
                    $data = $var->getData();
                    return $data;
                }
            }

        } catch (\Exception $e) {
        }

    }

    /**
     * @return mixed
     */
    public function addButtoncheck()
    {
        try {
            $customer_id = $this->httpContext->getValue('customer_id');
            $quote_id = $this->quoteFactory->create()
                ->getCollection()
                ->addFieldToSelect('quote_id')
                ->addFieldToFilter('customer_id', $customer_id)
                ->addFieldToFilter('status', 'active')
                ->getFirstItem()->getData('quote_id');
            $merchant_price_status = $this->quoteFactory->create()
                ->getCollection()->addFieldToSelect('merchant_quoted_price')
                ->addFieldToFilter('quote_id', $quote_id)->getFirstItem()
                ->getData('merchant_quoted_price');
            return $merchant_price_status;
        } catch (\Exception $e) {
        }
    }

    /**
     * @return mixed|string
     */
    public function quotestatus()
    {
        try {
            $quote_id = $this->httpContext->getValue('current_quote');
            $status = $this->quoteFactory->create()
                ->getCollection()->addFieldToSelect('customer_action_status')
                ->addFieldToFilter('quote_id', $quote_id)
                ->getFirstItem()
                ->getData('customer_action_status');
            if ($status == 'preparing') {
                return $status;
            } else {
                $result = 'Empty';
                return $result;
            }
        } catch (\Exception $e) {
        }
    }


    /**
     * @return string
     */
    public function submitCheck()
    {
        $submittedQuote = $this->getRequest()->getParam('id');
        if ($submittedQuote) {
            $this->customerSession->setSubmittedQuoteView('true');
            return 'submitted';
        } else {
            $this->customerSession->setSubmittedQuoteView('false');
        }
    }

    /**
     * @return mixed
     */
    public function addalltoCart()
    {
        try {
            $submittedQuote = $this->getRequest()->getParam('id');
            $price_quote_status = $this->quoteFactory->create()
                ->load($submittedQuote)
                ->getData('merchant_quoted_price');
            return $price_quote_status;
        } catch (\Exception $e) {
        }

    }

    /**
     * @return mixed
     */
    public function quotefinalStatus()
    {
        try {
            $submittedQuote = $this->getRequest()->getParam('id');
            $finalStatus = $this->quoteFactory->create()
                ->load($submittedQuote)
                ->getData('status');
            return $finalStatus;
        } catch (\Exception $e) {
        }
    }

    /**
     * @return float|int
     */
    public function storePriceTotal()
    {
        try {
            $current_Quote = $this->getRequest()->getParam('id');
            $storePrice = 0;
            $items = $this->collection->create()
                ->addFieldToFilter('quote_id', $current_Quote)
                ->getData();
            foreach ($items as $key => $value) {
                $storePrice = $storePrice + ($value['product_price'] * $value['product_quantity']);
            }
            return $storePrice;
        } catch (\Exception $e) {
        }
    }

    /**
     * @return float|int
     */
    public function quotePriceTotal()
    {
        try {
            $current_Quote = $this->getRequest()->getParam('id');
            $price_quote_status = $this->quoteFactory->create()
                ->load($current_Quote)
                ->getData('merchant_quoted_price');
            if ($price_quote_status == 'yes') {
                $quotePrice = 0;
                $items = $this->collection->create()
                    ->addFieldToFilter('quote_id', $current_Quote)
                    ->getData();
                foreach ($items as $key => $value) {
                    $quotePrice = $quotePrice + ($value['merchant_quoted_price'] * $value['product_quantity']);
                }
                return $quotePrice;
            } else {
                return 0;
            }
        } catch (\Exception $e) {
        }

    }

    public function quoteDelete()
    {
        if ($this->getRequest()->getParam('id')) {
            $quoteId = $this->getRequest()->getParam('id');
        } else {
            $quoteId = $this->httpContext->getValue('current_quote');
        }
        return $quoteId;
    }
}