<?php

namespace Sprinix\RequestQuote\Controller\Adminhtml\Checkquotes;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\Controller\ResultFactory;
use Magento\Ui\Component\MassAction\Filter;
use Sprinix\RequestQuote\Model\ResourceModel\Quote\CollectionFactory;
use Sprinix\RequestQuote\Model\QuoteFactory;

/**
 * Class MassDelete
 * @package Sprinix\RequestQuote\Controller\Adminhtml\Checkquotes
 */
class MassDelete extends Action
{

    /**
     * @var CollectionFactory
     */
    public $collectionFactory;

    /**
     * @var Filter
     */
    public $filter;

    /**
     * @var QuoteFactory
     */
    protected $quoteFactory;


    /**
     * MassDelete constructor.
     * @param Context $context
     * @param Filter $filter
     * @param CollectionFactory $collectionFactory
     * @param QuoteFactory $quoteFactory
     */
    public function __construct(
        Context $context,
        Filter $filter,
        CollectionFactory $collectionFactory,
        QuoteFactory $quoteFactory
    )
    {
        $this->filter = $filter;
        $this->collectionFactory = $collectionFactory;
        $this->quoteFactory = $quoteFactory;
        parent::__construct($context);
    }


    /**
     * @return mixed
     */
    public function execute()
    {
        try {
            $collection = $this->filter->getCollection($this->collectionFactory->create());


            $count = 0;
            foreach ($collection as $model) {
                $model = $this->quoteFactory->create()->load($model->getQuoteId());
                $model->delete();
                $count++;
            }
            $this->messageManager->addSuccess(__('A total of %1 Request Quote(s) have been deleted.', $count));
        } catch (\Exception $e) {
            $this->messageManager->addError(__($e->getMessage()));
        }
        return $this->resultFactory->create(ResultFactory::TYPE_REDIRECT)->setPath('*/*/index');
    }

    /**
     * @return bool
     */
    public function _isAllowed()
    {
        return $this->_authorization->isAllowed('Sprinix_RequestQuote::delete');
    }
}


