<?php

namespace Sprinix\RequestQuote\Controller\Index;

use Magento\Framework\App\Action\Context;
use Magento\Framework\View\Result\PageFactory;
use Sprinix\RequestQuote\Model\QuoteItemFactory;
use Magento\Framework\App\Action\Action;
use Magento\Framework\Controller\ResultFactory;
use Sprinix\RequestQuote\Model\QuoteFactory;
use Magento\Customer\Model\Session;
use Sprinix\RequestQuote\Helper\SubmitEmail;
use Magento\Framework\App\Http\Context as HttpContext;
use Psr\Log\LoggerInterface;

/**
 * Class Submitquotes
 * @package Sprinix\RequestQuote\Controller\AddTags
 */
class Submitquotes extends Action
{
    /**
     * @var PageFactory
     */
    protected $resultPageFactory;

    /**
     * @var quoteitemFactory
     */
    protected $quoteitemFactory;

    /**
     * @var \Magento\Customer\Model\Session
     */
    protected $customerSession;

    /**
     * @var \Request\Quote\Model\QuoteFactory
     */
    protected $quoteFactory;

    /**
     * @var \Sprinix\RequestQuote\Helper\SubmitEmail
     */
    protected $submitEmail;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * @var \Magento\Framework\App\Http\Context
     */
    protected $httpContext;

    /**
     * Submitquotes constructor.
     * @param QuoteFactory $quoteFactory
     * @param Session $CustomerSession
     * @param SubmitEmail $submitEmail
     * @param HttpContext $httpContext
     * @param Context $context
     * @param PageFactory $resultPageFactory
     * @param QuoteItemFactory $quoteitemFactory
     */
    public function __construct(
        QuoteFactory $quoteFactory,
        Session $CustomerSession,
        SubmitEmail $submitEmail,
        HttpContext $httpContext,
        Context $context,
        PageFactory $resultPageFactory,
        QuoteItemFactory $quoteitemFactory,
        LoggerInterface $logger
    )
    {
        $this->resultPageFactory = $resultPageFactory;
        $this->quoteitemFactory = $quoteitemFactory;
        $this->customerSession = $CustomerSession;
        $this->quoteFactory = $quoteFactory;
        $this->submitEmail = $submitEmail;
        $this->httpContext = $httpContext;
        $this->logger = $logger;

        parent::__construct($context);
    }

    /**
     * @return \Magento\Framework\App\ResponseInterface|\Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        try {
            $quantity = $this->getRequest()->getParams();
            foreach ($quantity as $key => $value) {
                $model = $this->quoteitemFactory->create()->load($key);
                $check = is_numeric($value);
                if ($value == 0 || empty($value) || $check == 0) {
                    $value = 1;
                }
                $model->setData('product_quantity', $value);
                $model->save();
            }
            $quantity = 0;
            $custid = $this->httpContext->getValue('customer_id');
            $models = $this->quoteFactory->create();
            $data = $models->getCollection()
                ->addFieldToFilter('customer_id', $custid)
                ->addFieldToFilter('customer_action_status', 'preparing')
                ->getFirstItem()
                ->getData();
            $quote_id = $data['quote_id'];
            $cust_email = $this->quoteFactory->create()
                ->getCollection()->addFieldToFilter('customer_id', $custid)
                ->addFieldToFilter('status', 'active')
                ->getFirstItem()
                ->getData('customer_email');
            $model = $this->quoteFactory->create()->load($quote_id);
            $model->setData('customer_action_status', 'submitted');
            $saveData = $model->save();
            $this->customerSession->setrequestQuoteQuantity($quantity);
            if ($saveData) {
                $this->submitEmail->sendEmail($cust_email);

                $this->messageManager->addSuccess(__("Your quote has been successfully sent for merchant review"));
            }
            $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
            $resultRedirect->setUrl($this->_redirect->getRefererUrl());
            return $resultRedirect;
        } catch (\Exception $e) {
            $this->logger->critical($e->getMessage());
        }
    }
}
